#!/bin/sh
# Script to build Drop Jobs 7.x-1.x
# Make sure the correct number of args was passed from the command line

if [ $# -eq 0 ]; then
  echo "Usage $0 target_build_dir"
  exit 1
fi

shift $((OPTIND-1))
MAKEFILE='build-drop_jobs.make'
TARGET=$1
# Make sure we have a target directory
if [ -z "$TARGET" ]; then
  echo "Usage $0 target_build_diri"
  exit 2
fi
CALLPATH=`dirname "$0"`
ABS_CALLPATH=`cd "$CALLPATH"; pwd -P`
BASE_PATH=`cd ..; pwd`

echo ''
echo ' /$$$$$$$     /$$$$$'
echo '| $$__  $$   |__  $$'
echo '| $$  \ $$      | $$'
echo '| $$  | $$      | $$'
echo '| $$  | $$ /$$  | $$'
echo '| $$  | $$| $$  | $$'
echo '| $$$$$$$/|  $$$$$$/'
echo '|_______/  \______/ '
echo ''
echo '================='
echo '    Drop Jobs    '
echo '================='

echo "\nThis command can be used to build the distribution.\n"
echo "  [1] Build distribution at $TARGET (in release mode)"
echo "  [2] Build distribution at $TARGET (in development mode)\n"
echo "Selection: \c"
read SELECTION

if [ $SELECTION = "1" ]; then

  echo "Building Drop Jobs distribution..."
  DRUSH_OPTS='--no-cache'

elif [ $SELECTION = "2" ]; then

  echo "Building Drop Jobs distrbution..."
  DRUSH_OPTS='--working-copy --no-gitinfofile --no-cache'

else
 echo "Invalid selection."
 exit 0
fi

# Temp move settings
if [ -f "$TARGET/sites/default/settings.php" ]; then
  echo "\nBacking up settings.php..."
  mv "$TARGET/sites/default/settings.php" settings.php
fi

# Verify the make file
set -e
echo 'Verifying make...'
drush verify-makefile

# Remove current drupal dir
echo 'Wiping Drupal directory...'
rm -rf "$TARGET"

# Do the build
echo 'Running drush make...'
drush make $DRUSH_OPTS "$ABS_CALLPATH/$MAKEFILE" "$TARGET"
set +e

# Build Symlinks
echo 'Setting up symlinks...'
DRUPAL=`cd "$TARGET"; pwd -P`
mkdir "$DRUPAL/sites/default/files"
chmod -R 777 "$DRUPAL/sites/default/files"
cp "$DRUPAL/sites/default/default.settings.php" "$DRUPAL/sites/default/settings.php"
chmod 777 "$DRUPAL/sites/default/settings.php"

# Move libraries from profile into site libraries
# Modules properly using Library API don't need this, but many modules
# don't support libraries in the profile (like WYSIWYG)
mv $DRUPAL/profiles/drop_jobs/libraries $DRUPAL/sites/all/libraries
