<?php

/*
 * Define minimum execution time required to operate.
 */
define('DRUPAL_MINIMUM_MAX_EXECUTION_TIME', 120);

/**
 * Implements hook_install_tasks()
 */
function drop_jobs_install_tasks(&$install_state) {
  // Increase maximum function nesting level to prevent install errors.
  $max_nesting_level = ini_get('xdebug.max_nesting_level');
  if ($max_nesting_level > 0 && $max_nesting_level <= '200') {
    ini_set('xdebug.max_nesting_level', 200);
  }

  // Try to increase the timeout value.
  $max_execution_time = (int)ini_get('max_execution_time');
  if ($max_execution_time && $max_execution_time < 240) {
    drupal_set_time_limit(240);
  }

  // Add our custom CSS file for the installation process.
  drupal_add_css(drupal_get_path('profile', 'drop_jobs') . '/drop_jobs.css');

  // Remove any status messages that might have been set. They are unneeded.
  drupal_get_messages('status', TRUE);

  $tasks = array();

  // Add the Panopoly theme selection to the installation process
  require_once(drupal_get_path('module', 'panopoly_theme') . '/panopoly_theme.profile.inc');
  $tasks = $tasks + panopoly_theme_profile_theme_selection_install_task($install_state);

// Need to rebuild search index tables since drop_jobs_search changes panopoly_search.
//  $tasks['drop_jobs_rebuild_search'] = array(
//    'type' => 'normal',
//  );

  return $tasks;
}

//function drop_jobs_rebuild_search() {
//  require_once(drupal_get_path('module', 'drop_jobs_search') . '/drop_jobs_search.install');
//  drop_jobs_search_rebuild_index();
//}

/**
 * Implements hook_install_tasks_alter()
 */
function drop_jobs_install_tasks_alter(&$tasks, $install_state) {
  // Magically go one level deeper in solving years of dependency problems
  require_once(drupal_get_path('module', 'panopoly_core') . '/panopoly_core.profile.inc');
  $tasks['install_load_profile']['function'] = 'panopoly_core_install_load_profile';
}

/**
 * Implements hook_form_FORM_ID_alter()
 */
function drop_jobs_form_install_configure_form_alter(&$form, $form_state) {
  // Hide some messages from various modules that are just too chatty!
  drupal_get_messages('status');
  drupal_get_messages('warning');

  // Set a default name for the dev site and change title's label.
  $form['site_information']['site_name']['#default_value'] = t('Drop Jobs');

  // Set a default country so we can benefit from it on Address Fields.
  $form['server_settings']['site_default_country']['#default_value'] = 'US';

  // Use "admin" as the default username.
  $form['admin_account']['account']['name']['#default_value'] = 'admin';

  // Set the default admin password.
  $form['admin_account']['account']['pass']['#value'] = 'admin';
}

/**
 * Implements hook_form_FORM_ID_alter()
 */
function drop_jobs_form_panopoly_theme_selection_form_alter(&$form, &$form_state, $form_id) {
  // Remove some themes tht we don't want to offer users.
//  unset($form['theme_wrapper']['theme']['#options']['radix']);
  unset($form['theme_wrapper']['theme']['#options']['radix_starter']);
  unset($form['theme_wrapper']['theme']['#options']['bartik']);
  unset($form['theme_wrapper']['theme']['#options']['garland']);

  // Set the default theme selection.
  $form['theme_wrapper']['theme']['#default_value'] = 'radix';
}
